#[repr(C, packed(1))]
pub struct JET_LGPOS {
pub ib: u16,
pub isec: u16,
pub lGeneration: i32,
}
Required features: "Win32_Storage_Jet"
Performs copy-assignment from
source.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.